@@ -50,6 +50,20 @@ def test_units(unit_str, dim, new_def):
     assert registry('1 ' + unit_str).dimensionality == dim
 
 
+def test_orders_of_magnitude():
+    # The registry recognizes units prefixed by an order of magnitude
+    assert registry('1.2 billion EUR').to('million EUR').magnitude == 1.2e3
+
+
+def test_kt():
+    # The registry should correctly interpret `kt` as a weight (not velocity)
+    assert str(registry('1000 kt').to('Mt')) == '1.0 megametric_ton'
+
+    # A default UnitRegistry should interpret `kt` as velocity
+    with pytest.raises(pint.DimensionalityError):
+        pint.UnitRegistry()('kt').to('Mt')
+
+
 @pytest.mark.parametrize('context, value',
                          [('AR5GWP100', 28),
                           ('AR4GWP100', 25),
